/**
 * @brief Falcon reader class implementation.
 * @file readFalcon.cpp
 * @version 1.5.1
 * @date March 4, 2016
 * @details Class for reading ARINC 708 data from a file. The Falcon derived
 * class implements a slightly modified format containing time information.
 * 
 * Version History:
 * Version 1.5.1 on March 4, 2016
 */

#include <math.h>
#include "readFalcon.h"

using namespace readerFalcon;

readFalcon::readFalcon(string fileName) throw (exception) : read708(fileName,98) {
    // 98 data words = 512 range bins + 2 extra words for time
    time = 0;
}

readFalcon::~readFalcon() {
}

void readFalcon::resetValues(void) {
    read708::resetValues();
    time = 0;
}

void readFalcon::determineGain(int gainWord) {
    if (gainWord == 63) {
        gain = 0.0f; // cal
    } else {
        gain = 3.0f - 2.0f*(float)gainWord/3.0f;
    }
    if (gain > 3.0f) {gain = 3.0f;} //max
    if (gain < -15.0f) {gain = -15.0f;} //min
}

void readFalcon::decodeFrame() {
    //call base class method for first 96 words
    nDataWords -= 2;
    read708::decodeFrame();
    //read two additional words for time
    time = ((blockData[nDataWords+1]<<16)+blockData[nDataWords]);
    //reset block size for next frame
    nDataWords +=2;
}

unsigned long readFalcon::getTime() {
    return time;
}