/**
 * @brief Falcon reader class definition.
 * @file readFalcon.h
 * @version 1.5.1
 * @date March 4, 2016
 * @details Class for reading ARINC 708 data from a file. The Falcon derived
 * class implements a slightly modified format containing time information.
 * 
 * Version History:
 * Version 1.5.1 on March 4, 2016
 */

#ifndef READFALCON_H
#define	READFALCON_H

#include "read708.h"

namespace readerFalcon {
using namespace reader708;
/**
 * @brief Extends 708 reader class.\n
 * Reader class for Falcon formatted radar data.
 * Used for opening a data file and reading in radar information
 * for each record.
 */
class readFalcon: public read708 {
public:
/**
 * @brief readFalcon class constructor
 * @param _fileName: the full name of the data file (including path and extension)
 * @Throws Standard runtime error exception
 * 
 * Creates and instance of the readFalcon class, opens the data file for reading,
 * and allocates memory for data buffers. Throws a standard runtime error
 * exception if the file cannot be opened or memory allocation fails.
 */
    readFalcon(string _fileName) throw (exception);
/**
 * @brief readFalcon class destructor
 * 
 * Closes the data file, frees data buffer memory, and deletes the class instance.
 */
    virtual ~readFalcon();
/**
 * @brief Get the time for the current frame
 * @return Time in seconds
 * 
 * This returns the time for the current frame in seconds since midnight
 * 1 January 1970. It is similar to Unix time.
 */
  unsigned long getTime(void);
private:
    unsigned long time;
    void resetValues(void);
    void determineGain(int _gainWord);
    void decodeFrame(void);
};
}

#endif	/* READFALCON_H */

